@@ -1,6 +1,7 @@
 import knowledge_clustering.distance as dist
 import copy
 
+
 def bagId(known_knowledges, kl):
     i = 0
     n = len(known_knowledges)
@@ -8,7 +9,10 @@ def bagId(known_knowledges, kl):
         i += 1
     return i
 
-def clustering(known_knowledges, unknown_knowledges, alpha, list_prefixes, scopes_meaning, lang):
+
+def clustering(
+    known_knowledges, unknown_knowledges, alpha, list_prefixes, scopes_meaning, lang
+):
     # Takes a list of lists of known knowledges, a list of unknown knowledges, a threshold alpha (positive float)
     # and modifies known_knowledges and unknown_knowledges so that at the end every notion of unknown_knowledges
     # is moved to some bag of known_knowledges. The bags of known_knowledges satisfy the following invariant:
@@ -48,6 +52,10 @@ def clustering(known_knowledges, unknown_knowledges, alpha, list_prefixes, scope
                 unknown_knowledges.remove(kl)
                 knowledges_processed_new.append(kl)
         # Every "new processed knowledge" that was known at the beginning of the while iteration
-        # becomes an "old processed knowledge" 
-        knowledges_processed_old += knowledges_processed_new[:size_knowledges_processed_new]
-        knowledges_processed_new = knowledges_processed_new[size_knowledges_processed_new:]
+        # becomes an "old processed knowledge"
+        knowledges_processed_old += knowledges_processed_new[
+            :size_knowledges_processed_new
+        ]
+        knowledges_processed_new = knowledges_processed_new[
+            size_knowledges_processed_new:
+        ]
